﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Imaging;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Telerik.Charting;
using Telerik.WinControls.UI;

namespace _897930_GridViewChartColumn
{
    public partial class Form1 : Form
    {
        private BindingList<Sale> salesBindingList = new BindingList<Sale>();
        private Random rand = new Random();

        public Form1()
        {
            InitializeComponent();
        
            this.GenerateSales();
            
            this.radGridView1.BestFitColumns(BestFitColumnMode.AllCells);
            this.radGridView1.AllowAddNewRow = false;
            this.radGridView1.TableElement.RowHeight = 200;
            
            this.Load += Form1_Load;
        }

        RadChartView chart;
        PieSeries series;
        protected override void OnShown(EventArgs e)
        {
            base.OnShown(e);

            foreach (var row in this.radGridView1.Rows)
            {
                List<int> numbers = (row.DataBoundItem as Sale).Numbers;
                chart = new RadChartView();
                chart.View.AreaType = ChartAreaType.Pie;
                series = new PieSeries();
                for (int i = 0; i < numbers.Count; i++)
                {
                    series.LabelsOffsetFromCenter = 0.5f;
                    series.DataPoints.Add(new PieDataPoint(numbers[i], "Item" + i));
                    series.ShowLabels = true;
                    chart.Series.Add(series);
                }

                chart.LoadElementTree();
                Application.DoEvents();

                chart.ChartElement.InvalidateMeasure(true);
                chart.ChartElement.UpdateLayout();
                Image img = null;
                using (MemoryStream stream = new MemoryStream())
                {
                    chart.ExportToImage(stream, new Size(200, 200), ImageFormat.Png);
                    img = Image.FromStream(stream);
                    img.Save(@"..\..\test.png");
                }

                row.Cells["Numbers"].Tag = img;
            }
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.radGridView1.DataSource = this.salesBindingList;
            this.radGridView1.Columns.Remove("Numbers");

            this.GenerateChartColumn();
        }

        private void GenerateSales()
        {
            for (int i = 1; i <= 5; i++)
            {
                List<int> numbers = new List<int>();
                numbers.Add(rand.Next(10, 40));
                numbers.Add(rand.Next(40, 100));
                numbers.Add(rand.Next(100, 150));
                numbers.Add(rand.Next(150, 200));
                salesBindingList.Add(new Sale()
                {
                    Id = i,
                    Name = "Sale " + i,
                    Numbers = numbers
                });   
            }
        }

        private void GenerateChartColumn()
        {
            GridViewChartColumn chartColumn = new GridViewChartColumn("Chart");
            chartColumn.Width = 200;
            chartColumn.FieldName = "Numbers";
            this.radGridView1.Columns.Add(chartColumn);

            GridViewCommandColumn col = new GridViewCommandColumn("Command");
            this.radGridView1.Columns.Add(col);
        }

        private void radButton1_Click(object sender, EventArgs e)
        {
            GridPrintStyle style = new MyGridPrintStyle();
            this.radGridView1.PrintStyle = style;
            RadPrintDocument document = new RadPrintDocument();
            document.AssociatedObject = this.radGridView1;

            RadPrintPreviewDialog dialog = new RadPrintPreviewDialog(document);
            dialog.Show();
        }
    }
}
